@@ -7,8 +7,8 @@ extern "Rust" {
     fn _image_from_bytes(bytes: &[u8]) -> Option<Image>;
     fn _svg_from_bytes(bytes: &[u8]) -> Option<Image>;
     fn _tex_id_from_image(image: &Image, frame: &mut epi::Frame<'_>) -> TextureId;
-    fn _load_image(path: String) -> Futurized<(),Image, String>;
-    fn _load_svg(path: String) -> Futurized<(),Image, String>;
+    fn _load_image(path: String) -> Futurized<(),Image>;
+    fn _load_svg(path: String) -> Futurized<(),Image>;
 }
 
 /// Example available on repository: https://github.com/Ar37-rs/egui-extras-lib
@@ -48,14 +48,14 @@ impl Image {
     }
 
     /// Image loader (.png, .gif, .jpg and .etc ) on top of image crate.
-    pub fn load_image(path: String) -> Futurized<(),Image, String> {
+    pub fn load_image(path: String) -> Futurized<(),Image> {
         unsafe {
             _load_image(path)
         }
     }
 
     /// SVG loader usvg, resvg, tiny-skia and image crates under the hood.
-    pub fn load_svg(path: String) -> Futurized<(),Image, String> {
+    pub fn load_svg(path: String) -> Futurized<(),Image> {
         unsafe {
             _load_svg(path)
         }
